@@ -11,7 +11,6 @@ import (
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/elbv2"
 	"github.com/aws/aws-sdk-go/service/route53"
-	"github.com/golang/protobuf/ptypes"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint-plugin-sdk/docs"
@@ -21,6 +20,7 @@ import (
 	"github.com/hashicorp/waypoint/builtin/aws/utils"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
+	"google.golang.org/protobuf/types/known/timestamppb"
 )
 
 type Releaser struct {
@@ -372,7 +372,7 @@ func (r *Releaser) resourceListenerCreate(
 
 	tgs := []*elbv2.TargetGroupTuple{
 		{
-			TargetGroupArn: &target.Arn,
+			TargetGroupArn: aws.String(target.Arn),
 			Weight:         aws.Int64(100),
 		},
 	}
@@ -380,7 +380,7 @@ func (r *Releaser) resourceListenerCreate(
 	if shouldCreateListener {
 		// create the listener to forward traffic to the target group
 		lo, err := elbsrv.CreateListener(&elbv2.CreateListenerInput{
-			LoadBalancerArn: &lbState.Arn,
+			LoadBalancerArn: aws.String(lbState.Arn),
 			Port:            aws.Int64(port),
 			Protocol:        aws.String(protocol),
 			Certificates:    certs,
@@ -394,6 +394,57 @@ func (r *Releaser) resourceListenerCreate(
 			},
 		})
 		if err != nil {
+			log.Warn("error creating listener", "error", err)
+			if aerr, ok := err.(awserr.Error); ok {
+				// CreateListener is idempotent, but if params change, such as `DefaultActions`,
+				// it will return a DuplicateListener error
+				switch aerr.Code() {
+				case elbv2.ErrCodeDuplicateListenerException:
+					// if DuplicateListener, we actually want to ModifyListener to use
+					// the newly created TargetGroup & Target pair.
+					//
+					// this requires us to fetch the listener ARN from the load balancer
+					log.Info("duplicate listener found, attempting to modify listener")
+					dlo, err := elbsrv.DescribeListeners(&elbv2.DescribeListenersInput{
+						LoadBalancerArn: aws.String(lbState.Arn),
+					})
+					if err != nil {
+						return err
+					}
+
+					// find the listener on our port
+					for _, ln := range dlo.Listeners {
+						if *ln.Port == port {
+							listener = ln
+						}
+					}
+
+					mlo, err := elbsrv.ModifyListener(&elbv2.ModifyListenerInput{
+						ListenerArn:  listener.ListenerArn,
+						Port:         aws.Int64(port),
+						Protocol:     aws.String(protocol),
+						Certificates: certs,
+						DefaultActions: []*elbv2.Action{
+							{
+								ForwardConfig: &elbv2.ForwardActionConfig{
+									TargetGroups: tgs,
+								},
+								Type: aws.String("forward"),
+							},
+						},
+					})
+					if err != nil {
+						return err
+					}
+
+					listener = mlo.Listeners[0]
+					state.Arn = *listener.ListenerArn
+
+					log.Info("modified listener", "arn", state.Arn)
+					// exit
+					return nil
+				}
+			}
 			return err
 		}
 		listener = lo.Listeners[0]
@@ -598,7 +649,7 @@ func (r *Releaser) resourceRecordSetDestroy(
 	r53 := route53.New(sess)
 
 	records, err := r53.ListResourceRecordSets(&route53.ListResourceRecordSetsInput{
-		HostedZoneId:    aws.String(lbState.ZoneId),
+		HostedZoneId:    aws.String(r.config.ZoneId),
 		StartRecordName: aws.String(state.FQDN),
 		StartRecordType: aws.String("A"),
 		MaxItems:        aws.String("1"),
@@ -620,7 +671,7 @@ func (r *Releaser) resourceRecordSetDestroy(
 		return nil
 	}
 
-	log.Debug("removing route53 record", "zone-id", lbState.ZoneId)
+	log.Debug("removing route53 record", "zone-id", r.config.ZoneId)
 	input := &route53.ChangeResourceRecordSetsInput{
 		ChangeBatch: &route53.ChangeBatch{
 			Changes: []*route53.Change{
@@ -639,7 +690,7 @@ func (r *Releaser) resourceRecordSetDestroy(
 			},
 			Comment: aws.String("managed by waypoint"),
 		},
-		HostedZoneId: aws.String(lbState.ZoneId),
+		HostedZoneId: aws.String(r.config.ZoneId),
 	}
 
 	result, err := r53.ChangeResourceRecordSets(input)
@@ -728,7 +779,7 @@ func (r *Releaser) Status(
 	var report sdk.StatusReport
 	report.External = true
 	defer func() {
-		report.GeneratedTime = ptypes.TimestampNow()
+		report.GeneratedTime = timestamppb.Now()
 	}()
 
 	if release.Region == "" {
