@@ -81,10 +81,13 @@ type TaskLauncherConfig struct {
 	// Optionally define various memory resource limits and requests for kubernetes pod containers
 	Memory *ResourceConfig `hcl:"memory,block"`
 
+	// Optionally define various ephemeral storage resource limits and requests for kubernetes pod containers
+	EphemeralStorage *ResourceConfig `hcl:"ephemeral_storage,block"`
+
 	// How long WatchTask should wait for a pod to startup. This option is specifically
 	// wordy because it's only for the WatchTask timing out waiting for the pod
 	// its watching to start up before it attempts to stream its logs.
-	WatchTaskStartupTimeoutSeconds int `hcl:watchtask_startup_timeout_seconds,optional"`
+	WatchTaskStartupTimeoutSeconds int `hcl:"watchtask_startup_timeout_seconds,optional"`
 }
 
 func (p *TaskLauncher) Documentation() (*docs.Documentation, error) {
@@ -152,6 +155,11 @@ task {
 		"cpu resource request to be added to the task container",
 	)
 
+	doc.SetField(
+		"ephemeral_storage",
+		"ephemeral_storage resource request to be added to the task container",
+	)
+
 	doc.SetField(
 		"image_pull_policy",
 		"pull policy to use for the task container image",
@@ -351,6 +359,26 @@ func (p *TaskLauncher) StartTask(
 		}
 	}
 
+	if p.config.EphemeralStorage != nil {
+		if p.config.EphemeralStorage.Request != "" {
+			q, err := k8sresource.ParseQuantity(p.config.EphemeralStorage.Request)
+			if err != nil {
+				return nil,
+					status.Errorf(codes.InvalidArgument, "failed to parse ephemeral-storage requested %q to k8s quantity: %s", p.config.EphemeralStorage.Request, err)
+			}
+			resourceRequests[corev1.ResourceEphemeralStorage] = q
+		}
+
+		if p.config.EphemeralStorage.Limit != "" {
+			q, err := k8sresource.ParseQuantity(p.config.EphemeralStorage.Limit)
+			if err != nil {
+				return nil,
+					status.Errorf(codes.InvalidArgument, "failed to parse ephemeral-storage limit %q to k8s quantity: %s", p.config.EphemeralStorage.Limit, err)
+			}
+			resourceLimits[corev1.ResourceEphemeralStorage] = q
+		}
+	}
+
 	resourceRequirements := corev1.ResourceRequirements{
 		Limits:   resourceLimits,
 		Requests: resourceRequests,
