@@ -3,12 +3,13 @@ package cli
 import (
 	"context"
 	"fmt"
-	"github.com/hashicorp/waypoint/internal/installutil"
-	"github.com/hashicorp/waypoint/internal/runnerinstall"
 	"sort"
 	"strings"
 	"time"
 
+	"github.com/hashicorp/waypoint/internal/installutil"
+	"github.com/hashicorp/waypoint/internal/runnerinstall"
+
 	"github.com/hashicorp/go-hclog"
 	"github.com/posener/complete"
 	"google.golang.org/grpc"
@@ -24,6 +25,7 @@ import (
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	"github.com/hashicorp/waypoint/pkg/serverclient"
 	"github.com/hashicorp/waypoint/pkg/serverconfig"
+	"github.com/hashicorp/waypoint/pkg/tokenutil"
 )
 
 type InstallCommand struct {
@@ -94,7 +96,11 @@ func (c *InstallCommand) Run(args []string) int {
 		}
 	}
 
-	result, err := p.Install(ctx, &serverinstall.InstallOpts{
+	// NOTE(briancain): Currently only the K8s Helm installer returns a bootstrap
+	// token. Helm also installs a runner, so we use this fact to determine if
+	// we should not only bootstrap a token but also install a runner. We could
+	// make this better in the future.
+	result, bootstrapToken, err := p.Install(ctx, &serverinstall.InstallOpts{
 		Log:            log,
 		UI:             c.ui,
 		ServerRunFlags: secondaryArgs,
@@ -123,6 +129,7 @@ func (c *InstallCommand) Run(args []string) int {
 	retries := 0
 	maxRetries := 12
 	sr := sg.Add("Attempting to make connection to server...") // stepgroup for retry ui
+	defer func() { sr.Abort() }()
 
 	for {
 		log.Info("connecting to the server so we can set the server config", "addr", contextConfig.Server.Address)
@@ -172,32 +179,50 @@ func (c *InstallCommand) Run(args []string) int {
 			terminal.WithErrorStyle(),
 		)
 		return 1
+	} else {
+		// Close the step here, so that the order of resolved steps makes sense to
+		// the user in case we fail on the "Retrieving initial auth token..." series
+		// Prior to this change, if we failed to retrieve the auth token, the resolved
+		// step with the error message would appear _before_ the above "Successfully connected
+		// to Waypoint server!" message and that is confusing
+		s.Update("Configured server connection")
+		s.Status(terminal.StatusOK)
+		s.Done()
+		s = sg.Add("")
 	}
 
 	client := pb.NewWaypointClient(conn)
 
 	s.Update("Retrieving initial auth token...")
 
-	// We need our bootstrap token immediately
 	var callOpts []grpc.CallOption
-	tokenResp, err := client.BootstrapToken(ctx, &empty.Empty{})
-	if err != nil && status.Code(err) != codes.PermissionDenied {
-		c.ui.Output(
-			"Error getting the initial token: %s\n\n%s",
-			clierrors.Humanize(err),
-			errInstallRunning,
-			terminal.WithErrorStyle(),
-		)
-		return 1
+	token := bootstrapToken
+	if bootstrapToken == "" {
+		// We need our bootstrap token immediately
+		tokenResp, err := client.BootstrapToken(ctx, &empty.Empty{})
+		if err != nil && status.Code(err) != codes.PermissionDenied {
+			c.ui.Output(
+				"Error getting the initial token: %s\n\n%s",
+				clierrors.Humanize(err),
+				errInstallRunning,
+				terminal.WithErrorStyle(),
+			)
+			return 1
+		}
+		// If we're not using the k8s install path, then we set the token
+		// based on the tokenResp
+		if tokenResp != nil {
+			token = tokenResp.Token
+		}
 	}
 
-	if tokenResp != nil {
+	if token != "" {
 		log.Debug("token received, setting on context")
 		contextConfig.Server.RequireAuth = true
-		contextConfig.Server.AuthToken = tokenResp.Token
+		contextConfig.Server.AuthToken = token
 	} else {
 		// try default context in case server was started again from install
-		defaultCtx, err := c.contextStorage.Default()
+		defaultCtxName, err := c.contextStorage.Default()
 		if err != nil {
 			c.ui.Output(
 				"Error getting default context to use existing auth token: %s\n\n%s\n\n%s",
@@ -209,12 +234,12 @@ func (c *InstallCommand) Run(args []string) int {
 			return 1
 		}
 
-		if defaultCtx != "" {
-			defaultCtxConfig, err := c.contextStorage.Load(defaultCtx)
+		if defaultCtxName != "" {
+			defaultCtxConfig, err := c.contextStorage.Load(defaultCtxName)
 			if err != nil {
 				c.ui.Output(
 					"Error loading the context %q to use existing auth token: %s\n\n%s\n\n%s",
-					defaultCtx,
+					defaultCtxName,
 					clierrors.Humanize(err),
 					errInstallToken,
 					errInstallRunning,
@@ -265,8 +290,10 @@ func (c *InstallCommand) Run(args []string) int {
 		}
 	}
 
+	// TODO this should eventually not use StaticToken but something that can
+	// setup access via oauth if the token contains that as well.
 	callOpts = append(callOpts, grpc.PerRPCCredentials(
-		serverclient.StaticToken(contextConfig.Server.AuthToken)))
+		tokenutil.StaticToken(contextConfig.Server.AuthToken)))
 
 	// This is our default, so let's actually set the timestamp if not set on the CLI
 	if c.contextName == "" {
@@ -340,9 +367,17 @@ func (c *InstallCommand) Run(args []string) int {
 	s.Update("Server installed and configured!")
 	s.Done()
 
+	// NOTE(briancain): Right now we rely on the fact that only K8S returns a bootstrap
+	// token from the installation interface helper. Since we know helm sets up
+	// a bootstrap job AS WELL AS a runner, we don't need to install another runner
+	// or another runner profile.
 	if c.flagRunner {
+		existingODRConfigSetup := false
+		if bootstrapToken != "" {
+			existingODRConfigSetup = true
+		}
 		// we pass nil for the ODR config because it's a fresh install
-		if code := installRunner(c.Ctx, log, client, c.ui, p, advertiseAddr, nil); code > 0 {
+		if code := installRunner(c.Ctx, log, client, c.ui, p, advertiseAddr, nil, existingODRConfigSetup); code > 0 {
 			return code
 		}
 	}
@@ -475,6 +510,7 @@ func installRunner(
 	p serverinstall.Installer,
 	advertiseAddr *pb.ServerConfig_AdvertiseAddr,
 	odrConfig *pb.OnDemandRunnerConfig,
+	existingODRConfigSetup bool,
 ) int {
 	sg := ui.StepGroup()
 	defer sg.Wait()
@@ -509,11 +545,6 @@ func installRunner(
 		AuthToken:     resp.Token,
 	}
 
-	// We set the ID to be "static" since it is the initial static runner
-	// Specific platform implementations should add the suffix -runner to
-	// resource names
-	id := "static"
-
 	// Install!
 	s.Update("Installing runner...")
 	err = p.InstallRunner(ctx, &runnerinstall.InstallOpts{
@@ -522,7 +553,7 @@ func installRunner(
 		Cookie:          config.Config.Cookie,
 		ServerAddr:      advertiseAddr.Addr,
 		AdvertiseClient: connConfig,
-		Id:              id,
+		Id:              installutil.Id,
 	})
 
 	if err != nil {
@@ -534,43 +565,44 @@ func installRunner(
 		)
 		return 1
 	}
-	s.Update("Runner %q installed", id)
+	s.Update("Runner %q installed", installutil.Id)
 	s.Done()
 
-	err = installutil.AdoptRunner(ctx, ui, client, id, advertiseAddr.Addr)
+	err = installutil.AdoptRunner(ctx, ui, client, installutil.Id, advertiseAddr.Addr)
 	if err != nil {
 		ui.Output("Error adopting runner: %s", clierrors.Humanize(err), terminal.WithErrorStyle())
 		return 1
 	}
 
-	// If this installation platform supports an out-of-the-box ODR
-	// config then we set that up. This enables on-demand runners to
-	// work immediately.
-	if odc, ok := p.(serverinstall.OnDemandRunnerConfigProvider); ok {
-		s = sg.Add("Registering on-demand runner configuration...")
+	// NOTE(briancain): Some installers like the Kubernetes Helm install already sets up a runner profile
+	// when the server is installed. For this reason, we shouldn't create another
+	// bootstrap runner profile.
+	if !existingODRConfigSetup {
+		// If this installation platform supports an out-of-the-box ODR
+		// config then we set that up. This enables on-demand runners to
+		// work immediately.
+		if odc, ok := p.(installutil.OnDemandRunnerConfigProvider); ok {
+			s = sg.Add("Registering on-demand runner configuration...")
 
-		if odrConfig == nil {
-			odrConfig = odc.OnDemandRunnerConfig()
+			if odrConfig == nil {
+				odrConfig = odc.OnDemandRunnerConfig()
+			}
+
+			odrConfig.Name = odrConfig.PluginType + "-bootstrap-profile"
+
+			_, err = client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
+				Config: odrConfig,
+			})
+			if err != nil {
+				ui.Output("Error creating ondemand runner: %s", clierrors.Humanize(err), terminal.WithErrorStyle())
+				return 1
+			} else {
+				s.Update("Registered ondemand runner!")
+				s.Status(terminal.StatusOK)
+			}
+
+			s.Done()
 		}
-
-		odrConfig.Name = odrConfig.PluginType + "-bootstrap-profile"
-		if err != nil {
-			ui.Output("Error getting version: %s", clierrors.Humanize(err), terminal.WithErrorStyle())
-			return 1
-		}
-
-		_, err = client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
-			Config: odrConfig,
-		})
-		if err != nil {
-			ui.Output("Error creating ondemand runner: %s", clierrors.Humanize(err), terminal.WithErrorStyle())
-			return 1
-		} else {
-			s.Update("Registered ondemand runner!")
-			s.Status(terminal.StatusOK)
-		}
-
-		s.Done()
 	}
 
 	return 0
